package dev.fitko.fitconnect.core.events;

import dev.fitko.fitconnect.api.domain.model.event.EventLogPayload;
import dev.fitko.fitconnect.api.domain.validation.ValidationResult;
import dev.fitko.fitconnect.api.exceptions.ValidationException;
import lombok.Getter;

import java.util.ArrayList;
import java.util.List;
import java.util.UUID;

@Getter
class ValidationContext {
    private final EventLogPayload eventLogPayload;
    private final List<ValidationResult> validationResults;

    ValidationContext(final EventLogPayload eventLogPayload) {
        this.eventLogPayload = eventLogPayload;
        this.validationResults = new ArrayList<>();
    }

    void addResult(final ValidationResult validationResult) {
        if (validationResult.hasError()) {
            this.validationResults.add(validationResult);
        }
    }

    void addResult(final boolean test, final String message) {
        if (!test) {
            addResult(ValidationResult.error(new ValidationException(message)));
        }
    }

    void addError(final String message) {
        addResult(ValidationResult.error(new ValidationException(message)));
    }

    void addError(final Exception exception) {
        addResult(ValidationResult.error(new ValidationException(exception.getMessage(),exception)));
    }

    UUID getDestinationId(){
        return this.eventLogPayload.getDestinationId();
    }

    UUID getCaseId(){
        return this.eventLogPayload.getCaseId();
    }
}
